@@ -1,5 +1,5 @@
 "bounds" <-
-function (nums, dup.inds=FALSE) {
+function (nums, dup.inds=FALSE, pre.sort=TRUE) {
 
   if(dup.inds) {
     ## bounds of concetive duplicated numbers 
@@ -19,7 +19,11 @@ function (nums, dup.inds=FALSE) {
       names(bounds) <- c("start", "end", "length")
       return(bounds)
     }
-    nums <- sort(unique(nums))
+
+    if(pre.sort) {
+      ## should we pre-sort...
+      nums <- sort(unique(nums))
+    }
     bounds <- nums[1]
     nums.start <- nums[1]
     diff.i <- 1
