@@ -7,7 +7,6 @@ function(aln, id=NULL,
                    refine = FALSE,
                    extra.args = "") {
 
-  # extra.args = " -tree2 tree.out"
 
   as.aln <- function(mat, id=NULL) {
     if(is.null(id))
@@ -23,13 +22,14 @@ function(aln, id=NULL,
   toaln <- tempfile()  
   write.fasta(aln, file=toaln)
   
-  if(!seqgroup)  extra.args <- paste(extra.args,"-stable")
+###  if(!seqgroup)  extra.args <- paste(extra.args,"-stable")
   if(refine) extra.args <- paste(extra.args,"-refine")
   if(protein) {
     extra.args <- paste(extra.args,"-seqtype protein")
   } else { extra.args <- paste(extra.args,"-seqtype dna") }
   
-  cmd <- paste(exepath, "muscle -in ",toaln," -out ",file, " ",extra.args, sep="")
+  cmd <- paste(exepath, "muscle -in ",toaln," -out ",
+               file," ",extra.args, sep="")
   cat(cmd)
   
   if (os1 == "windows") {
@@ -37,7 +37,21 @@ function(aln, id=NULL,
   } else {
     system(cmd)
   }
+
+  ### Update for muscle v3.8 with no "-stable" option
+  ###  Thu Aug 26 18:29:38 PDT 2010
+  naln <- read.fasta(file)
+  if(!seqgroup) {
+    ord <- match(naln$id, aln$id)
+    if( any( duplicated(ord) ) ) {
+      stop(" Duplicated sequence id's, so can't perserve input order\n\tPlease run with 'seqgroup=TRUE' option")
+    }
+    naln$id <- naln$id[ord]
+    naln$ali <- naln$ali[ord,]
+  }
+  ####
+  
   unlink(toaln)
-  return(read.fasta(file))
+  return(naln)
 }
 
